
--------------------
How to save datasets
--------------------

An instance of a :ref:`csdm_api` object is serialized as a csdf/csdfe
json-formated file with the :meth:`~csdmpy.csdm.CSDM.save` method.
